<?php

namespace Litecms\PaymentSetting\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\PaymentSetting\Models\PaymentSetting;

class PaymentSettingPolicy
{

    /**
     * Determine if the given user can view the payment_setting.
     *
     * @param UserPolicy $user
     * @param PaymentSetting $payment_setting
     *
     * @return bool
     */
    public function view(UserPolicy $user, PaymentSetting $payment_setting)
    {
        if ($user->canDo('payment_setting.payment_setting.view') && $user->isAdmin()) {
            return true;
        }

        return $payment_setting->user_id == user_id() && $payment_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can create a payment_setting.
     *
     * @param UserPolicy $user
     * @param PaymentSetting $payment_setting
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('payment_setting.payment_setting.create');
    }

    /**
     * Determine if the given user can update the given payment_setting.
     *
     * @param UserPolicy $user
     * @param PaymentSetting $payment_setting
     *
     * @return bool
     */
    public function update(UserPolicy $user, PaymentSetting $payment_setting)
    {
        if ($user->canDo('payment_setting.payment_setting.edit') && $user->isAdmin()) {
            return true;
        }

        return $payment_setting->user_id == user_id() && $payment_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given payment_setting.
     *
     * @param UserPolicy $user
     * @param PaymentSetting $payment_setting
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, PaymentSetting $payment_setting)
    {
        return $payment_setting->user_id == user_id() && $payment_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given payment_setting.
     *
     * @param UserPolicy $user
     * @param PaymentSetting $payment_setting
     *
     * @return bool
     */
    public function verify(UserPolicy $user, PaymentSetting $payment_setting)
    {
        if ($user->canDo('payment_setting.payment_setting.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given payment_setting.
     *
     * @param UserPolicy $user
     * @param PaymentSetting $payment_setting
     *
     * @return bool
     */
    public function approve(UserPolicy $user, PaymentSetting $payment_setting)
    {
        if ($user->canDo('payment_setting.payment_setting.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
